toolbar {
    display:block;
    background-color: rgb(192,192,192);
    border-bottom: solid darkGray 1px;
    border-top: solid white 1px;
    border-left: solid white 1px;
    border-right: solid darkGray 1px;
    font: 10pt sans-serif;
    min-height:20px;
}
toolbar[collapsed="true"] {
	display:none;
}
toolbar[hidden="true"] {
	display:none;
}

toolbox { 
        background-color:darkgray;
}

:toolbox-normal {
	background-color: rgb(192,192,192);
	color: lightgray;
	border-bottom: solid darkGray 1px;
	border-top: solid white 0px;
	border-left: solid white 0px;
	border-right: solid darkGray 1px;
}
:toolbox-rollover {
	background-color: purple;
	color: green;
	border-bottom: solid darkGray 1px;
	border-top: solid white 0px;
	border-left: solid white 0px;
	border-right: solid darkGray 1px;
}

window { 
  background-color:rgb(192,192,192);
  display: block; 
}

button.throbber {
	width: 32px;
	height: 32px;
	background-color:red;
	background-image:url("resource:/res/throbber/anims00.gif");
}
throbber[busy] {
	background-image:url("resource:/res/throbber/anims07.gif");
}

titledbutton:button-focus {
	border: none;
}

broadcaster {
	display: none;
}

observes {
	display: none;
}

progressmeter {
        display:block;
        border: black thin groove;
        color : #086975;         
}

:progressmeter-stripe {
	color: gray;
}

titledbutton {
  display: inline;

  color:black; 

  padding: 2px;
  margin: 2px;


  font: 8pt sans-serif;
}


titledbutton[pseudoclass~="hover"] {
  border: 1px outset white;

  padding: 1px;
}
 
titledbutton[pseudoclass~="hover"]:-moz-outline {
   border : 1px solid black;
}
 
titledbutton[pseudoclass~="active"] {

  border: 1px inset white;

  padding-left: 2px;
  padding-right: 0px;
  padding-top: 2px;
  padding-bottom: 0px;
}

titledbutton[pseudoclass~="active"]:-moz-outline {
   border : 1px solid black;
}
 
titledbutton::-moz-focus-inner {
}

titledbutton::-moz-focus-outer {
}

titledbutton[pseudoclass~="focus"] {
}

titledbutton[pseudoclass~="focus"]::-moz-focus-inner {
}

titledbutton[pseudoclass~="focus"]::-moz-focus-outer {
}

titledbutton[pseudoclass~="disabled"] {
}
 
